@@ -19,7 +19,6 @@
 # TODO (deoktr): add variable to import or not b64decode
 # TODO (deoktr): replace eval with ast.literal_eval: https://beta.ruff.rs/docs/rules/suspicious-eval-usage/
 
-import logging
 import random
 from base64 import b64encode, b85encode
 from enum import Enum
@@ -37,6 +36,7 @@ from tokenize import (
 )
 
 from pof.errors import PofError
+from pof.logger import logger
 from pof.utils.cipher import ShiftCipher
 from pof.utils.generator import AdvancedGenerator
 
@@ -49,11 +49,12 @@ class StringsObfuscator:
         ADDITION = 2  # FIXME (deoktr): doesn't seems to work <
         ONLY_ADDITION = 3
         BASE85 = 4
-        UNICODE = 5
-        SHIFT = 6
-        REPLACE = 7
-        REVERSE = 8
-        ONE_ON_N = 9
+        HEX = 5
+        UNICODE = 6
+        SHIFT = 7
+        REPLACE = 8
+        REVERSE = 9
+        ONE_ON_N = 10
 
     ALL = (
         Strats.BASE64,
@@ -69,8 +70,8 @@ class StringsObfuscator:
         b64decode_name: str = "b64decode",
         b85decode_name: str = "b85decode",
         *,
-        import_b64decode: bool = False,
-        import_b85decode: bool = False,
+        import_b64decode: bool = True,
+        import_b85decode: bool = True,
     ) -> None:
         self.import_b64decode = import_b64decode
         self.import_b85decode = import_b85decode
@@ -134,6 +135,18 @@ class StringsObfuscator:
             (RPAR, ")"),
         ]
 
+    @staticmethod
+    def hex(tokval: str):
+        # Hello --> \x48\x65\x6c\x6c\x6f
+        raw_string = eval(tokval)  # noqa: S307
+        if isinstance(raw_string, bytes):
+            raw_string = raw_string.decode()
+        encoded = ""
+        for c in raw_string:
+            hexcode = f"\\x{hex(ord(c))[2:]:0>2}" if not c.isdigit() else c  # noqa: FURB116
+            encoded += hexcode
+        return [(STRING, f"'{encoded}'")]
+
     @staticmethod
     def unicode(tokval: str):
         # Hell --> \u0048\u0065\u006C\u006C
@@ -142,7 +155,7 @@ class StringsObfuscator:
             raw_string = raw_string.decode()
         encoded = ""
         for c in raw_string:
-            ucode = f"\\u{hex(ord(c))[2:]:0>4}" if not c.isdigit() else c
+            ucode = f"\\u{hex(ord(c))[2:]:0>4}" if not c.isdigit() else c  # noqa: FURB116
             encoded += ucode
         return [(STRING, f"'{encoded}'")]
 
@@ -309,7 +322,7 @@ class StringsObfuscator:
             (OP, ")"),
         ]
 
-    def obfuscate_string(self, tokval: str, next_tokval: str):  # NOQA: C901
+    def obfuscate_string(self, tokval: str, next_tokval: str):  # noqa: C901
         # TODO (deoktr): consider f"" u"" ur"" b"" r"" strings
         # consider empty strings
         # consider calling function on whole string "".format()
@@ -327,6 +340,7 @@ class StringsObfuscator:
             strategies = list(strategies)
             strategies.extend(
                 [
+                    self.Strats.HEX,
                     self.Strats.UNICODE,
                     self.Strats.SHIFT,
                 ],
@@ -342,6 +356,8 @@ class StringsObfuscator:
             tokens = self.only_additions(tokval)
         elif strategy == self.Strats.BASE85:
             tokens = self.obf_base85(tokval)
+        elif strategy == self.Strats.HEX:
+            tokens = self.hex(tokval)
         elif strategy == self.Strats.UNICODE:
             tokens = self.unicode(tokval)
         elif strategy == self.Strats.SHIFT:
@@ -353,7 +369,7 @@ class StringsObfuscator:
         elif strategy == self.Strats.ONE_ON_N:
             tokens = self.string_one_on_n(tokval)
         else:
-            logging.error("unsupported strategy %s", strategy)
+            logger.error("unsupported strategy %s", strategy)
             return None
 
         return tokens
@@ -425,8 +441,8 @@ class StringsObfuscator:
             ]:
                 try:
                     new_tokens = self.obfuscate_string(tokval, next_tokval)
-                except Exception:
-                    logging.exception("failed to get new token")
+                except BaseException:  # noqa: BLE001
+                    logger.exception("failed to get new token")
 
             if new_tokens:
                 result.extend(new_tokens)
